summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLeo Chang <schang@qca.qualcomm.com>2014-01-17 19:03:37 -0800
committerPrakash Dhavali <pdhavali@qca.qualcomm.com>2014-01-26 20:06:34 -0800
commit5fd4e3192298483c30f4f95fed623202bd7de051 (patch)
treefdc0afc9807edd55b5c437778b7f52e4aea32a97
parentff5e5c77784d5fc531ae1d3ccfd657293763a751 (diff)
wlan: cld, MCC increase TX buffer size.
MCC scenario. FW slowdown to drain frame from host. 700 buffer size is too small and too many packet lost happen on host side. To mitigate problem buffer size should be increased to 1500. Change-Id: I01a2e86765dd5fa5e55f71e5673ffc787719fdd0 CRs-fixed: 602219
-rw-r--r--CORE/SERVICES/COMMON/ol_cfg.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/CORE/SERVICES/COMMON/ol_cfg.h b/CORE/SERVICES/COMMON/ol_cfg.h
index cfcbe03646ea..eba23e99c1de 100644
--- a/CORE/SERVICES/COMMON/ol_cfg.h
+++ b/CORE/SERVICES/COMMON/ol_cfg.h
@@ -408,15 +408,19 @@ static inline int
ol_tx_cfg_max_tx_queue_depth_ll(ol_pdev_handle pdev)
{
/*
* Store up to 700 frames for a paused vdev.
* For example, if the vdev is sending 300 Mbps of traffic, and the
* PHY is capable of 600 Mbps, then it will take 56 ms for the PHY to
* drain both the 700 frames that are queued initially, plus the next
* 700 frames that come in while the PHY is catching up.
* So in this example scenario, the PHY will remain fully utilized
* in a MCC system that has a channel-switching period of 56 ms or less.
+ * 700 frames calculation was correct when FW drain packet without
+ * any overhead. Actual situation drain overhead will slowdown drain
+ * speed. And channel period is less than 56 msec
+ * Worst scenario, 1500 frames should be stored in host.
*/
- return 700;
+ return 1500;
}
#endif /* _OL_CFG__H_ */
@@ -408,15 +408,19 @@ static inline int
{
/*
- * Store up to 700 frames for a paused vdev.
+ * Store up to 1500 frames for a paused vdev.
* For example, if the vdev is sending 300 Mbps of traffic, and the
* PHY is capable of 600 Mbps, then it will take 56 ms for the PHY to